# Changelog for Wartungsplan

## Under development

## Version 1.0rc4

 - Update dependencies
 - Drop support for Python 3.8 (importlib-metadata 8.7.0 doesn't support it)
 - Drop support for Python 3.9 (icalendar requires Python >=3.10)
 - TLS certificate config options for the OTRS backend

## Version 1.0rc3

 - Tools: downloadExchange
 - End-Date: Changed default range from +1 day to plus one week
 - downloadExchange: is now an installed binary

## Version 0.4

 - RRules now support lists like BYDAY=MO,TU,WE
 - The directory option in config now has the more explanatory name calendarfile
 - The config option ticekttitel no longer exists since it should always be
   given in the event Summary
 - OTRS: the event Summary is now correctly assigned to ticket title
